###############################
# MAROLLA ET AL. 2019
# Assessing the effect of predator control on an endangered goose population subjected to predator-mediated food web dynamics
# Journal of Applied Ecology
#
# R code to run data analysis
###############################

# PREPARE DATASETS
goose<-read.csv2("Lesser_White_fronted_Goose_population_data.csv", header=T)
library(plyr)
goose<-rename(goose, c("CulledRedfox"="fox"))
goose<-rename(goose, c("X..pair.spring..2cy.incl.."="TotPairSpring"))
goose$Year <- as.factor(goose$Year)

goose_ny <- goose[3:23,]

# number of reindeer carcasses
goose_ny$n.carcass <- c(244, 280, 329 , 316 , 544, 232, 137, 88, 109, 243, 266, 370, 425, 322, 357, 621, 503, 524, 317, 205 , 181) 

# onset of spring
gimms <- read.csv2("Onset_of_spring.csv")
cor(gimms$gimms6v1[5:21], gimms$spring[5:21])
goose_ny$spring.gimms <- gimms$gimms6v1

goose_ny$not.brood<-goose_ny$PairSpring-goose_ny$Broods

# small rodents
rod_stab <- read.table("small_rodent_data.txt") # import stabbursnes rodent data
rod_stab_sum <- aggregate(rod_stab[,3], by=list(rod_stab$year), sum) # sum densities (only rufocanus)
rod_stab_sum <- rod_stab_sum$x

goose_ny_stab <- goose_ny[c(3:21),] # time series 1998-2016
goose_ny_stab$rod_stab_sum <- rod_stab_sum[-20]/8 # take out 2017 and divide sum by 8 grids
goose_ny_stab$rod_stab_sum_lag <- c(NA, goose_ny_stab$rod_stab_sum[-nrow(goose_ny_stab)])

# period variable (P1 = NO fox culling, P2 = fox culling)
goose_ny_stab$period <- as.factor(c(rep("P1", 10), rep("P2", 9)))

# rodent cycle variable
goose_ny_stab$cycle <- as.factor(c(1,1,1,2,2,2,2,3,3,3,3,4,4,4,4,5,5,5,5))


################################################################
# MODELLING
################################################################

# PROPORTION OF SUCCESSFUL BREEDING PAIRS
library(MASS)
library(nlme)

mod_prop_breed1 <- glmmPQL(cbind(Broods, not.brood)~rod_stab_sum*n.carcass + spring.gimms, random =~1|cycle, family=quasibinomial, data = goose_ny_stab)
summary(mod_prop_breed1)
intervals(mod_prop_breed1, level = 0.95, method = "boot", nsim = 9999, boot.type = "norm")

mod_prop_breed2 <- glmmPQL(cbind(Broods, not.brood)~rod_stab_sum + n.carcass + spring.gimms, random =~1|cycle, family=quasibinomial, data = goose_ny_stab)
summary(mod_prop_breed2)
intervals(mod_prop_breed2, level = 0.95, method = "boot", nsim = 9999, boot.type = "norm")

mod_prop_breed3 <- glmmPQL(cbind(Broods, not.brood)~rod_stab_sum + n.carcass*period, random =~1|cycle, family=quasibinomial, data = goose_ny_stab)
summary(mod_prop_breed3)
intervals(mod_prop_breed3, level = 0.95, method = "boot", nsim = 9999, boot.type = "norm")

mod_prop_breed4 <- glmmPQL(cbind(Broods, not.brood)~rod_stab_sum*period + n.carcass, random =~1|cycle, family=quasibinomial, data = goose_ny_stab)
summary(mod_prop_breed4)
intervals(mod_prop_breed4, level = 0.95, method = "boot", nsim = 9999, boot.type = "norm")

mod_prop_breed5 <- glmmPQL(cbind(Broods, not.brood)~rod_stab_sum + n.carcass + period, random =~1|cycle, family=quasibinomial, data = goose_ny_stab)
summary(mod_prop_breed5)
intervals(mod_prop_breed5, level = 0.95, method = "boot", nsim = 9999, boot.type = "norm")

mod_prop_breed6 <- glmmPQL(cbind(Broods, not.brood)~rod_stab_sum + rod_stab_sum_lag*period, random =~1|cycle, family=quasibinomial, data = goose_ny_stab)
summary(mod_prop_breed6)
intervals(mod_prop_breed6, level = 0.95, method = "boot", nsim = 9999, boot.type = "norm")

mod_prop_breed7 <- glmmPQL(cbind(Broods, not.brood)~rod_stab_sum + rod_stab_sum_lag + period, random =~1|cycle, family=quasibinomial, data = goose_ny_stab)
summary(mod_prop_breed7)
intervals(mod_prop_breed7, level = 0.95, method = "boot", nsim = 9999, boot.type = "norm")


# AVERAGE BROOD SIZE

goose_ny_stab$logPairSpring <- log(goose_ny_stab$PairSpring)

mod_j1 <- glmmPQL(JuvenilAutumn~rod_stab_sum*n.carcass+spring.gimms+offset(logPairSpring),random =~1|cycle, data = goose_ny_stab, family = quasipoisson)
summary(mod_j1)
intervals(mod_j1, level = 0.95, method = "boot", nsim = 9999, boot.type = "norm")

mod_j2 <- glmmPQL(JuvenilAutumn~rod_stab_sum+n.carcass+spring.gimms+offset(logPairSpring),random =~1|cycle, data = goose_ny_stab, family = quasipoisson)
summary(mod_j2)
intervals(mod_j2, level = 0.95, method = "boot", nsim = 9999, boot.type = "norm")

mod_j3 <- glmmPQL(JuvenilAutumn~rod_stab_sum+n.carcass*period+offset(logPairSpring),random =~1|cycle, data = goose_ny_stab, family = quasipoisson)
summary(mod_j3)
intervals(mod_j3, level = 0.95, method = "boot", nsim = 9999, boot.type = "norm")

mod_j4 <- glmmPQL(JuvenilAutumn~rod_stab_sum*period+n.carcass+offset(logPairSpring),random =~1|cycle, data = goose_ny_stab, family = quasipoisson)
summary(mod_j4)
intervals(mod_j4, level = 0.95, method = "boot", nsim = 9999, boot.type = "norm")

mod_j5 <- glmmPQL(JuvenilAutumn~rod_stab_sum+n.carcass+period+offset(logPairSpring),random =~1|cycle, data = goose_ny_stab, family = quasipoisson)
summary(mod_j5)
intervals(mod_j5, level = 0.95, method = "boot", nsim = 9999, boot.type = "norm")

mod_j6 <- glmmPQL(JuvenilAutumn~rod_stab_sum+rod_stab_sum_lag*period+offset(logPairSpring),random=~1|cycle, data=goose_ny_stab, family=quasipoisson)
summary(mod_j6)
intervals(mod_j6, level = 0.95, method="boot", nsim=999, boot.type="norm", which="fixed")

mod_j7 <- glmmPQL(JuvenilAutumn~rod_stab_sum+rod_stab_sum_lag+period+offset(logPairSpring),random=~1|cycle, data=goose_ny_stab, family=quasipoisson)
summary(mod_j7)
intervals(mod_j7, level = 0.95, method="boot", nsim=999, boot.type="norm", which = "fixed")


# ADULTS AVOIDING THE RISKIER ROUTE

mod_adb1 <- glm(AdultAutumn~rod_stab_sum*n.carcass+spring.gimms+offset(log(AdultPairs)), data = goose_ny_stab,
                family = quasipoisson)
summary(mod_adb1)
confint(mod_adb1, level = 0.95, method = "boot", nsim = 9999, boot.type = "norm")

mod_adb2 <- glm(AdultAutumn~rod_stab_sum+n.carcass+spring.gimms+offset(log(AdultPairs)), data = goose_ny_stab,
                family = quasipoisson)
summary(mod_adb2)
confint(mod_adb2, level = 0.95, method = "boot", nsim = 9999, boot.type = "norm")

mod_adb3 <- glm(AdultAutumn~rod_stab_sum+n.carcass*period+offset(log(AdultPairs)), data = goose_ny_stab,
                family = quasipoisson)
summary(mod_adb3)
confint(mod_adb3, level = 0.95, method = "boot", nsim = 9999, boot.type = "norm")

mod_adb4 <- glm(AdultAutumn~rod_stab_sum*period+n.carcass+offset(log(AdultPairs)), data = goose_ny_stab,
                family = quasipoisson)
summary(mod_adb4)
confint(mod_adb4, level = 0.95, method = "boot", nsim = 9999, boot.type = "norm")

mod_adb5 <- glm(AdultAutumn~rod_stab_sum+n.carcass+period+offset(log(AdultPairs)), data = goose_ny_stab,
                family = quasipoisson)
summary(mod_adb5)
confint(mod_adb5, level = 0.95, method = "boot", nsim = 9999, boot.type = "norm")

mod_adb6 <- glm(AdultAutumn~rod_stab_sum+rod_stab_sum_lag*period+offset(log(AdultPairs)), data = goose_ny_stab,
                family = quasipoisson)
summary(mod_adb6)
confint(mod_adb6, level = 0.95, method = "boot", nsim = 9999, boot.type = "norm")

mod_adb7 <- glm(AdultAutumn~rod_stab_sum+rod_stab_sum_lag+period+offset(log(AdultPairs)), data = goose_ny_stab,
                family = quasipoisson)
summary(mod_adb7)
confint(mod_adb7, level = 0.95, method = "boot", nsim = 9999, boot.type = "norm")

###################################
# CPUE MODEL (APPENDIX S2)
###################################

effort_data<-read.csv2("fox_culling_management_data.csv", header=T)
names(effort_data)

effort_data$removed<-NA
effort_data$removed[1]<-0

effort_data$day<-as.numeric(substr(effort_data$Day, 1,2))
effort_data$day<-as.numeric(substr(effort_data$Day, 1,2))

for (i in 2:nrow(effort_data)){
  if (effort_data$Year[i]==effort_data$Year[i-1]) effort_data$removed[i]<-effort_data$removed[i-1]+effort_data$fox_tot[i-1]
  if (effort_data$Year[i]!=effort_data$Year[i-1]) effort_data$removed[i]<-0
}



rmax<-aggregate(effort_data$removed, list(effort_data$Year),max)
colnames(rmax)<-c("Year", "Rmax")
rmax$Year<-as.numeric(as.character(rmax$Year))
effort_data<-merge(effort_data,rmax)
head(effort_data)


LL.summary<-function(x){list(data.frame(par=x$par, se= sqrt(diag(solve(x$hessian)))),value=x$value, AIC=x$value+2*length(x$par))}
LL.AIC<-function(x){list(data.frame(value=x$value, AIC=x$value+2*length(x$par)))}
LL.summary.nlm<-function(x){list(data.frame(par=x$estimate, se= sqrt(diag(solve(x$hessian)))),value=x$minimum, AIC=x$minimum+2*length(x$estimate))}

ef<-effort_data[effort_data$Year%in%c(2012:2016),]


remove.cpue.f3<-function(beta){
  R=ef$removed
  Rmax=ef$Rmax
  effort=ef$km_tot/1000
  nshot=ef$fox_tot
  Ndiff=model.matrix(~-1+factor(Year), ef)%*%(beta[1:5])
  Nt=Ndiff+Rmax-R
  ce<-rep(beta[6], nrow(ef))
  p<-1-exp(-ce*effort)
  ep<-ifelse(p<0.00001, 0.00001, p)
  temp1 <- lgamma(Nt + 1) - lgamma(Nt - nshot + 1) - lgamma(nshot + 1)
  temp2 <- nshot * log(ep)
  temp3 <- (Nt - nshot) * log(1 - ep)
  LL <- -2*sum(temp1 + temp2 + temp3)
  LL}

res3<-optim(fn=remove.cpue.f3, par=c(rep(100,5),0.2), hessian=T, control=list(maxit=10000))
res3
LL.summary(res3)
LL.AIC(res3)
LL.AIC(res2)
LL.AIC(res1)
exp(res3$par)

res3b<-nlm(f=remove.cpue.f3, p=c(rep(100, 5), rep(0.4,1)), hessian=T, iterlim=10000)
res3b
LL.summary.nlm(res3b)

rmax$Rmax/(res3b$estimate[1:5]+rmax$Rmax)

#  par 1

alpha<-res3b$estimate[2:6]
remove.cpue.f3.1ci<-function(alpha){
  R=ef$removed
  Rmax=ef$Rmax
  effort=ef$km_tot/1000
  nshot=ef$fox_tot
  beta<-c(beta.est1.iter,alpha)
  Ndiff=model.matrix(~-1+factor(Year), ef)%*%(beta[1:5])
  Nt=Ndiff+Rmax-R
  ce<-rep(beta[6], nrow(ef))
  p<-1-exp(-ce*effort)
  ep<-ifelse(p<0.00001, 0.00001, p)
  temp1 <- lgamma(Nt + 1) - lgamma(Nt - nshot + 1) - lgamma(nshot + 1)
  temp2 <- nshot * log(ep)
  temp3 <- (Nt - nshot) * log(1 - ep)
  LL <- -2*sum(temp1 + temp2 + temp3)
  LL}

beta.est<-seq(2, 600, length=100)
dat.1ci<-rep(NA, 100)
start.par<-res3b$estimate[2:6]
for (i in 1:100){
  beta.est1.iter<-beta.est[i]
  test<-nlm(f=remove.cpue.f3.1ci, p=start.par, iterlim=10000)
  dat.1ci[i]<-test$minimum-res3b$minimum
  start.par<-c(jitter(res3b$estimate[2]),jitter(res3b$estimate[3]),jitter(res3b$estimate[4]),jitter(res3b$estimate[5]),jitter(res3b$estimate[6]) )
  rm(test)
}

plot(beta.est,dat.1ci, ylim=c(0, 4)) 
abline(h=3.8)

cbind(beta.est,dat.1ci)


beta.est1.iter<-358
nlm(f=remove.cpue.f3.1ci, p=start.par, iterlim=10000)$minimum-res3b$minimum

beta.est1.iter<-223
nlm(f=remove.cpue.f3.1ci, p=start.par, iterlim=10000)$minimum-res3b$minimum


par1.ci<-c(223, 358)

#  par 2

alpha<-c(res3b$estimate[1], res3b$estimate[3:6])
remove.cpue.f3.2ci<-function(alpha){
  R=ef$removed
  Rmax=ef$Rmax
  effort=ef$km_tot/1000
  nshot=ef$fox_tot
  beta<-c(alpha[1], beta.est1.iter,alpha[2:5])
  Ndiff=model.matrix(~-1+factor(Year), ef)%*%(beta[1:5])
  Nt=Ndiff+Rmax-R
  ce<-rep(beta[6], nrow(ef))
  p<-1-exp(-ce*effort)
  ep<-ifelse(p<0.00001, 0.00001, p)
  temp1 <- lgamma(Nt + 1) - lgamma(Nt - nshot + 1) - lgamma(nshot + 1)
  temp2 <- nshot * log(ep)
  temp3 <- (Nt - nshot) * log(1 - ep)
  LL <- -2*sum(temp1 + temp2 + temp3)
  LL}

beta.est<-seq(50, 250, length=100)
dat.1ci<-rep(NA, 100)
start.par<-c(res3b$estimate[1], res3b$estimate[3:6])
for (i in 1:100){
  beta.est1.iter<-beta.est[i]
  test<-nlm(f=remove.cpue.f3.2ci, p=start.par, iterlim=10000)
  dat.1ci[i]<-test$minimum-res3b$minimum
  #start.par<-c(jitter(res3b$estimate[1]),jitter(res3b$estimate[3]),jitter(res3b$estimate[4]),jitter(res3b$estimate[5]),jitter(res3b$estimate[6]) )
  rm(test)
}

plot(beta.est,dat.1ci) #, ylim=c(0, 4)
abline(h=3.8)

cbind(beta.est,dat.1ci)


beta.est1.iter<-95
nlm(f=remove.cpue.f3.2ci, p=start.par, iterlim=10000)$minimum-res3b$minimum

beta.est1.iter<-184
nlm(f=remove.cpue.f3.2ci, p=start.par, iterlim=10000)$minimum-res3b$minimum


par2.ci<-c(95, 183)


#  par 3

alpha<-c(res3b$estimate[1:2], res3b$estimate[4:6])
remove.cpue.f3.3ci<-function(alpha){
  R=ef$removed
  Rmax=ef$Rmax
  effort=ef$km_tot/1000
  nshot=ef$fox_tot
  beta<-c(alpha[1:2], beta.est1.iter,alpha[3:5])
  Ndiff=model.matrix(~-1+factor(Year), ef)%*%(beta[1:5])
  Nt=Ndiff+Rmax-R
  ce<-rep(beta[6], nrow(ef))
  p<-1-exp(-ce*effort)
  ep<-ifelse(p<0.00001, 0.00001, p)
  temp1 <- lgamma(Nt + 1) - lgamma(Nt - nshot + 1) - lgamma(nshot + 1)
  temp2 <- nshot * log(ep)
  temp3 <- (Nt - nshot) * log(1 - ep)
  LL <- -2*sum(temp1 + temp2 + temp3)
  LL}

beta.est<-seq(50, 250, length=100)
dat.1ci<-rep(NA, 100)
start.par<-c(res3b$estimate[1:2], res3b$estimate[4:6])
for (i in 1:100){
  beta.est1.iter<-beta.est[i]
  test<-nlm(f=remove.cpue.f3.3ci, p=start.par, iterlim=10000)
  dat.1ci[i]<-test$minimum-res3b$minimum
  #start.par<-c(jitter(res3b$estimate[1]),jitter(res3b$estimate[3]),jitter(res3b$estimate[4]),jitter(res3b$estimate[5]),jitter(res3b$estimate[6]) )
  rm(test)
}

plot(beta.est,dat.1ci) #, ylim=c(0, 4)
abline(h=3.8)

cbind(beta.est,dat.1ci)


beta.est1.iter<-91
nlm(f=remove.cpue.f3.3ci, p=start.par, iterlim=10000)$minimum-res3b$minimum

beta.est1.iter<-183
nlm(f=remove.cpue.f3.3ci, p=start.par, iterlim=10000)$minimum-res3b$minimum


par3.ci<-c(91, 183)


#  par 4

alpha<-c(res3b$estimate[1:3], res3b$estimate[5:6])
remove.cpue.f3.4ci<-function(alpha){
  R=ef$removed
  Rmax=ef$Rmax
  effort=ef$km_tot/1000
  nshot=ef$fox_tot
  beta<-c(alpha[1:3], beta.est1.iter,alpha[4:5])
  Ndiff=model.matrix(~-1+factor(Year), ef)%*%(beta[1:5])
  Nt=Ndiff+Rmax-R
  ce<-rep(beta[6], nrow(ef))
  p<-1-exp(-ce*effort)
  ep<-ifelse(p<0.00001, 0.00001, p)
  temp1 <- lgamma(Nt + 1) - lgamma(Nt - nshot + 1) - lgamma(nshot + 1)
  temp2 <- nshot * log(ep)
  temp3 <- (Nt - nshot) * log(1 - ep)
  LL <- -2*sum(temp1 + temp2 + temp3)
  LL}

beta.est<-seq(20, 150, length=100)
dat.1ci<-rep(NA, 100)
start.par<-c(res3b$estimate[1:3], res3b$estimate[5:6])
for (i in 1:100){
  beta.est1.iter<-beta.est[i]
  test<-nlm(f=remove.cpue.f3.4ci, p=start.par, iterlim=10000)
  dat.1ci[i]<-test$minimum-res3b$minimum
  #start.par<-c(jitter(res3b$estimate[1]),jitter(res3b$estimate[3]),jitter(res3b$estimate[4]),jitter(res3b$estimate[5]),jitter(res3b$estimate[6]) )
  rm(test)
}

plot(beta.est,dat.1ci) #, ylim=c(0, 4)
abline(h=3.8)

cbind(beta.est,dat.1ci)


beta.est1.iter<-46
nlm(f=remove.cpue.f3.4ci, p=start.par, iterlim=10000)$minimum-res3b$minimum

beta.est1.iter<-124
nlm(f=remove.cpue.f3.4ci, p=start.par, iterlim=10000)$minimum-res3b$minimum


par4.ci<-c(46, 124)



#  par 5

alpha<-c(res3b$estimate[1:4], res3b$estimate[6])
remove.cpue.f3.5ci<-function(alpha){
  R=ef$removed
  Rmax=ef$Rmax
  effort=ef$km_tot/1000
  nshot=ef$fox_tot
  beta<-c(alpha[1:4], beta.est1.iter,alpha[5])
  Ndiff=model.matrix(~-1+factor(Year), ef)%*%(beta[1:5])
  Nt=Ndiff+Rmax-R
  ce<-rep(beta[6], nrow(ef))
  p<-1-exp(-ce*effort)
  ep<-ifelse(p<0.00001, 0.00001, p)
  temp1 <- lgamma(Nt + 1) - lgamma(Nt - nshot + 1) - lgamma(nshot + 1)
  temp2 <- nshot * log(ep)
  temp3 <- (Nt - nshot) * log(1 - ep)
  LL <- -2*sum(temp1 + temp2 + temp3)
  LL}

beta.est<-seq(200, 400, length=100)
dat.1ci<-rep(NA, 100)
start.par<-c(res3b$estimate[1:4], res3b$estimate[6])
for (i in 1:100){
  beta.est1.iter<-beta.est[i]
  test<-nlm(f=remove.cpue.f3.5ci, p=start.par, iterlim=10000)
  dat.1ci[i]<-test$minimum-res3b$minimum
  #start.par<-c(jitter(res3b$estimate[1]),jitter(res3b$estimate[3]),jitter(res3b$estimate[4]),jitter(res3b$estimate[5]),jitter(res3b$estimate[6]) )
  rm(test)
}

plot(beta.est,dat.1ci) #, ylim=c(0, 4)
abline(h=3.8)

cbind(beta.est,dat.1ci)


beta.est1.iter<-218
nlm(f=remove.cpue.f3.5ci, p=start.par, iterlim=10000)$minimum-res3b$minimum

beta.est1.iter<-360
nlm(f=remove.cpue.f3.5ci, p=start.par, iterlim=10000)$minimum-res3b$minimum

par5.ci<-c(218, 360)


#  par 6

alpha<-c(res3b$estimate[1:4], res3b$estimate[5])
remove.cpue.f3.6ci<-function(alpha){
  R=ef$removed
  Rmax=ef$Rmax
  effort=ef$km_tot/1000
  nshot=ef$fox_tot
  beta<-c(alpha[1:5], beta.est1.iter)
  Ndiff=model.matrix(~-1+factor(Year), ef)%*%(beta[1:5])
  Nt=Ndiff+Rmax-R
  ce<-rep(beta[6], nrow(ef))
  p<-1-exp(-ce*effort)
  ep<-ifelse(p<0.00001, 0.00001, p)
  temp1 <- lgamma(Nt + 1) - lgamma(Nt - nshot + 1) - lgamma(nshot + 1)
  temp2 <- nshot * log(ep)
  temp3 <- (Nt - nshot) * log(1 - ep)
  LL <- -2*sum(temp1 + temp2 + temp3)
  LL}

beta.est<-seq(0.001, 0.2, length=100)
dat.1ci<-rep(NA, 100)
start.par<-c(res3b$estimate[1:4], res3b$estimate[5])
for (i in 1:100){
  beta.est1.iter<-beta.est[i]
  test<-nlm(f=remove.cpue.f3.6ci, p=start.par, iterlim=10000)
  dat.1ci[i]<-test$minimum-res3b$minimum
  #start.par<-c(jitter(res3b$estimate[1]),jitter(res3b$estimate[3]),jitter(res3b$estimate[4]),jitter(res3b$estimate[5]),jitter(res3b$estimate[6]) )
  rm(test)
}

plot(beta.est,dat.1ci, ylim=c(0, 10))
abline(h=3.84)

cbind(beta.est,dat.1ci)


beta.est1.iter<-0.029
nlm(f=remove.cpue.f3.6ci, p=start.par, iterlim=10000)$minimum-res3b$minimum

beta.est1.iter<-0.158
nlm(f=remove.cpue.f3.6ci, p=start.par, iterlim=10000)$minimum-res3b$minimum

par6.ci<-c(0.028, 0.158)






shot<-aggregate(effort_data$fox_tot, list(effort_data$Year),sum)    

shot$x/res3b$estimate[1:5]


data.shot.pop.est<-data.frame(yr=as.numeric(shot[,1]), fox.shot=shot$x, fox.pop.est=res3b$estimate[1:5]+rmax$Rmax, end.pop.est=res3b$estimate[1:5])
data.shot.pop.est$uci.fox.pop.est<-c(par1.ci[2], par2.ci[2], par3.ci[2], par4.ci[2], par5.ci[2]) +rmax$Rmax
data.shot.pop.est$lci.fox.pop.est<-c(par1.ci[1], par2.ci[1], par3.ci[1], par4.ci[1], par5.ci[1])+rmax$Rmax
data.shot.pop.est$uci.end.pop.est<-c(par1.ci[2], par2.ci[2], par3.ci[2], par4.ci[2], par5.ci[2]) 
data.shot.pop.est$lci.end.pop.est<-c(par1.ci[1], par2.ci[1], par3.ci[1], par4.ci[1], par5.ci[1])
data.shot.pop.est$prop.shot<-data.shot.pop.est$fox.shot/data.shot.pop.est$fox.pop.est
data.shot.pop.est$uci.prop.shot<-data.shot.pop.est$fox.shot/data.shot.pop.est$lci.fox.pop.est
data.shot.pop.est$lci.prop.shot<-data.shot.pop.est$fox.shot/data.shot.pop.est$uci.fox.pop.est
data.shot.pop.est$effort<-aggregate(effort_data$km_tot, list(effort_data$Year),sum)$x
library(gplots)

par(mfrow=c(2,2))
plot(data.shot.pop.est$yr,data.shot.pop.est$prop.shot, las=1, cex=2, pch=16, ylab="Estimated proportion of fox population shot", xlab="Year", ylim=c(0,0.5), cex.lab=1.3)
plotCI(data.shot.pop.est$yr,data.shot.pop.est$prop.shot, li=data.shot.pop.est$lci.prop.shot, ui=data.shot.pop.est$uci.prop.shot,add=T, lwd=1, col=0, barcol="black", gap=0.5, sfrac=0.01) 

plot(data.shot.pop.est$yr,data.shot.pop.est$fox.pop.est, las=1, cex=2, pch=16, ylab="Fox population", xlab="Year", ylim=c(0,600), cex.lab=1.3)
plotCI(data.shot.pop.est$yr,data.shot.pop.est$fox.pop.est, li=data.shot.pop.est$lci.fox.pop.est, ui=data.shot.pop.est$uci.fox.pop.est,add=T, lwd=1, col=0, barcol="black", gap=0.5, sfrac=0.01) 
points(data.shot.pop.est$yr,data.shot.pop.est$fox.shot, pch=1, cex=2)
legend("top", legend=c("Estimated initial N", "N shot"), pch=c(16,1), cex=1.3)

plot(data.shot.pop.est$yr,data.shot.pop.est$effort, las=1, cex=2, pch=16, ylab="Total effort (km)", xlab="Year", cex.lab=1.3)


plot(data.shot.pop.est$effort, data.shot.pop.est$prop.shot, las=1, cex=2, pch=16, ylab="Estimated proportion of fox population shot", xlab="Total effort (km)", cex.lab=1.3)
abline(lm(data.shot.pop.est$prop.shot~data.shot.pop.est$effort))
#abline(lm(data.shot.pop.est$prop.shot~-1+data.shot.pop.est$effort), lty=2)   # Intercept = 0
legend("topleft", legend=c("y = a + b * effort/1000", "a=0.124, se=0.021", "b=0.073, se=0.005" ))

summary(lm(data.shot.pop.est$prop.shot~I(data.shot.pop.est$effort/1000)))

offset.val<-0.05
par(mfrow=c(1,1))
plot(data.shot.pop.est$yr-offset.val,data.shot.pop.est$fox.pop.est, las=1, cex=2, pch=16, ylab="Fox population", xlab="Year", ylim=c(0,600), cex.lab=1.3)
plotCI(data.shot.pop.est$yr-offset.val,data.shot.pop.est$fox.pop.est, li=data.shot.pop.est$lci.fox.pop.est, ui=data.shot.pop.est$uci.fox.pop.est,add=T, lwd=1, col=0, barcol="black", gap=0.5, sfrac=0.01) 
lines(data.shot.pop.est$yr-offset.val,data.shot.pop.est$fox.pop.est, lty=1, lwd=2)
points(data.shot.pop.est$yr+offset.val,data.shot.pop.est$end.pop.est, pch=1, cex=2)
plotCI(data.shot.pop.est$yr+offset.val,data.shot.pop.est$end.pop.est, li=data.shot.pop.est$lci.end.pop.est, ui=data.shot.pop.est$uci.end.pop.est,add=T, lwd=1, col=0, barcol="black", gap=0.5, sfrac=0.01) 
lines(data.shot.pop.est$yr+offset.val,data.shot.pop.est$end.pop.est, lty=2, lwd=2)

legend("top", legend=c("Estimated initial N", "N after culling"), pch=c(16,1), cex=1.3)






















